@@ -1,14 +1,7 @@
 from typing import List
-from enum import Enum
 from . import env_lines as __env_lines
+from ..objects import EnvType
 from ..utils import path_utils
-def __env_dict_from_lines(__env_lines: List[str]):
-    env_lines = __env_lines.copy()
-    env_lines.sort()
-    env_kv_pairs = [line.split("=", 1) for line in env_lines if "=" in line]
-    return {key: value for (key, value) in env_kv_pairs}
-
-
 
 def __env_dict_from_lines(__env_lines: List[str]):
     env_lines = __env_lines.copy()
@@ -17,7 +10,6 @@ def __env_dict_from_lines(__env_lines: List[str]):
     return {key: value for (key, value) in env_kv_pairs}
 
 
-
 def docker_compose_dict(__docker_compose_src: str):
     return __env_dict_from_lines(__env_lines.docker_compose_lines(__docker_compose_src))
 
@@ -32,15 +24,6 @@ def dotenv_dict(__dotenv_src: str):
 
 
 
-class EnvType(Enum):
-
-    DOTENV = 1
-    DOCKERFILE = 2
-    DOCKER_COMPOSE = 3
-    NONE = 4
-
-
-
 def env_dict(path: str = None, src: str = None, env: EnvType = EnvType.NONE):
     if src is not None:
         if env == EnvType.DOCKER_COMPOSE:
